==> webform_gohighlevel-1.0.0.tar.gz: webform_gohighlevel/src/Plugin/WebformHandler/GoHighLevelHandler.php <==
<?php

namespace Drupal\webform_gohighlevel\Plugin\WebformHandler;

use Drupal\webform\Plugin\WebformHandlerBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\WebformSubmissionInterface;
use GuzzleHttp\Exception\RequestException;

/**
 * Sends Webform submissions to GoHighLevel.
 *
 * @WebformHandler(
 *   id = "gohighlevel_handler",
 *   label = @Translation("GoHighLevel Handler"),
 *   category = @Translation("CRM"),
 *   description = @Translation("Send webform submissions to GoHighLevel."),
 *   cardinality = \Drupal\webform\Plugin\WebformHandlerInterface::CARDINALITY_SINGLE,
 *   results = TRUE,
 * )
 */
class GoHighLevelHandler extends WebformHandlerBase {

  /**
   * Default configuration.
   */
  public function defaultConfiguration() {
    return [
      'api_key' => '',
      'field_mapping' => [],
	  'custom_tag' => '', // Add a default value for the custom tag.
    ] + parent::defaultConfiguration();
  }

  /**
   * Build the configuration form.
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $webform = $this->getWebform();
    $elements = $webform->getElementsInitializedFlattenedAndHasValue();

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#description' => $this->t('Enter the GoHighLevel API key.'),
      '#default_value' => $this->configuration['api_key'] ?? '',
      '#maxlength' => 256,
      '#required' => TRUE,
    ];
	  
	// Custom tag field.
    $form['custom_tag'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom Tag'),
      '#description' => $this->t('Enter a custom tag for this webform. This will help identify the source of the contact in GoHighLevel.'),
      '#default_value' => $this->configuration['custom_tag'] ?? '',
      '#maxlength' => 256,
    ];

    $form['field_mapping'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Field Mapping'),
      '#description' => $this->t('Map your webform fields to GoHighLevel fields.'),
    ];

    $webform_options = [];
    foreach ($elements as $key => $element) {
      $webform_options[$key] = $element['#title'] ?? $key;
    }

    $gohighlevel_fields = [
      'firstName' => $this->t('First Name'),
      'lastName' => $this->t('Last Name'),
      'email' => $this->t('Email'),
      'phone' => $this->t('Phone'),
      'notes' => $this->t('Message'),
    ];

    foreach ($gohighlevel_fields as $gohighlevel_field => $label) {
      $form['field_mapping'][$gohighlevel_field] = [
        '#type' => 'select',
        '#title' => $label,
        '#options' => $webform_options,
        '#default_value' => $this->configuration['field_mapping'][$gohighlevel_field] ?? '',
        '#empty_option' => $this->t('- Select a Webform field -'),
      ];
    }

    return $form;
  }

  /**
   * Submit configuration form.
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['api_key'] = $form_state->getValue('api_key');
	$this->configuration['custom_tag'] = $form_state->getValue('custom_tag'); // Save the custom tag.
    $this->configuration['field_mapping'] = $form_state->getValue('field_mapping');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * Submit form handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state, WebformSubmissionInterface $webform_submission) {
    // Retrieve API key from the handler's configuration.
    $api_key = trim($this->configuration['api_key'] ?? '');
	$custom_tag = trim($this->configuration['custom_tag'] ?? '');

    // Get the field mappings.
    $field_mapping = $this->configuration['field_mapping'];
    $data = $webform_submission->getData();

    // Prepare the payload based on the mapped fields.
    $payload = [];
    foreach ($field_mapping as $gohighlevel_field => $webform_field) {
      if ($gohighlevel_field === 'notes') {
        // Add the custom message field to 'customField'.
        $payload['customField'] = [
          'webform_message' => $data[$webform_field] ?? '',
        ];
      } else {
        if (isset($data[$webform_field])) {
          $payload[$gohighlevel_field] = $data[$webform_field];
        }
      }
    }

    // Add the custom tag if provided.
    if (!empty($custom_tag)) {
      $payload['tags'] = [$custom_tag];
    }

    $url = 'https://rest.gohighlevel.com/v1/contacts/';

    try {
      // Make the API request.
      \Drupal::httpClient()->post($url, [
        'headers' => [
          'Authorization' => 'Bearer ' . $api_key,
          'Content-Type' => 'application/json',
        ],
        'body' => json_encode($payload),
      ]);
    }
    catch (RequestException $e) {
      // Log the error for administrators in case of API failures.
      \Drupal::logger('webform_gohighlevel')->error('API error: @message', ['@message' => $e->getMessage()]);
    }
  }
}

==> webform_gohighlevel-1.0.1.tar.gz: webform_gohighlevel/src/Plugin/WebformHandler/GoHighLevelHandler.php <==
<?php

namespace Drupal\webform_gohighlevel\Plugin\WebformHandler;

use Drupal\webform\Plugin\WebformHandlerBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\WebformSubmissionInterface;
use GuzzleHttp\Exception\RequestException;

/**
 * Sends Webform submissions to GoHighLevel.
 *
 * @WebformHandler(
 *   id = "gohighlevel_handler",
 *   label = @Translation("GoHighLevel Handler"),
 *   category = @Translation("CRM"),
 *   description = @Translation("Send webform submissions to GoHighLevel."),
 *   cardinality = \Drupal\webform\Plugin\WebformHandlerInterface::CARDINALITY_SINGLE,
 *   results = TRUE,
 * )
 */
class GoHighLevelHandler extends WebformHandlerBase {

  /**
   * Default configuration.
   */
  public function defaultConfiguration() {
    return [
      'api_key' => '',
      'field_mapping' => [],
      'custom_tag' => '', // Allow a custom tag per webform.
    ] + parent::defaultConfiguration();
  }

  /**
   * Build the configuration form.
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $webform = $this->getWebform();
    $elements = $webform->getElementsInitializedFlattenedAndHasValue();

    // API Key field.
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#description' => $this->t('Enter the GoHighLevel API key.'),
      '#default_value' => $this->configuration['api_key'] ?? '',
      '#maxlength' => 256,
      '#required' => TRUE,
    ];

    // Custom tag field.
    $form['custom_tag'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom Tag'),
      '#description' => $this->t('Enter a custom tag for this webform submission.'),
      '#default_value' => $this->configuration['custom_tag'] ?? '',
      '#maxlength' => 256,
    ];

    // Field mapping section.
    $form['field_mapping'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Field Mapping'),
      '#description' => $this->t('Map your webform fields to GoHighLevel fields.'),
    ];

    $webform_options = [];
    foreach ($elements as $key => $element) {
      $webform_options[$key] = $element['#title'] ?? $key;
    }

    $gohighlevel_fields = [
      'firstName' => $this->t('First Name'),
      'lastName' => $this->t('Last Name'),
      'email' => $this->t('Email'),
      'phone' => $this->t('Phone'),
      'notes' => $this->t('Message'),
      'address1' => $this->t('Street Address'),
      'city' => $this->t('City'),
      'state' => $this->t('State'),
      'postalCode' => $this->t('Postal Code'),
    ];

    foreach ($gohighlevel_fields as $gohighlevel_field => $label) {
      $form['field_mapping'][$gohighlevel_field] = [
        '#type' => 'select',
        '#title' => $label,
        '#options' => $webform_options,
        '#default_value' => $this->configuration['field_mapping'][$gohighlevel_field] ?? '',
        '#empty_option' => $this->t('- Select a Webform field -'),
      ];
    }

    return $form;
  }

  /**
   * Submit configuration form.
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['api_key'] = $form_state->getValue('api_key');
    $this->configuration['custom_tag'] = $form_state->getValue('custom_tag'); // Save the custom tag.
    $this->configuration['field_mapping'] = $form_state->getValue('field_mapping');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * Submit form handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state, WebformSubmissionInterface $webform_submission) {
    // Retrieve API key and custom tag from the handler's configuration.
    $api_key = trim($this->configuration['api_key'] ?? '');
    $custom_tag = trim($this->configuration['custom_tag'] ?? '');

    // Get the field mappings.
    $field_mapping = $this->configuration['field_mapping'];
    $data = $webform_submission->getData();

    // Prepare the payload based on the mapped fields.
    $payload = [];
    foreach ($field_mapping as $gohighlevel_field => $webform_field) {
      if ($gohighlevel_field === 'notes') {
        // Add the custom message field to 'customField'.
        $payload['customField'] = [
          'webform_message' => $data[$webform_field] ?? '',
        ];
      } else {
        if (isset($data[$webform_field])) {
          $payload[$gohighlevel_field] = $data[$webform_field];
        }
      }
    }

    // Add the custom tag if provided.
    if (!empty($custom_tag)) {
      $payload['tags'] = [$custom_tag];
    }

    $url = 'https://rest.gohighlevel.com/v1/contacts/';

    try {
      // Make the API request.
      \Drupal::httpClient()->post($url, [
        'headers' => [
          'Authorization' => 'Bearer ' . $api_key,
          'Content-Type' => 'application/json',
        ],
        'body' => json_encode($payload),
      ]);
    }
    catch (RequestException $e) {
      // Log the error for debugging.
      \Drupal::logger('webform_gohighlevel')->error('API error: @message', ['@message' => $e->getMessage()]);
    }
  }
}
